@@ -1,5 +1,6 @@
 import signal
 from contextlib import contextmanager
+from nctoolkit.session import session_info
 
 
 class TimeoutException(Exception):
@@ -19,7 +20,7 @@ def time_limit(seconds):
         signal.alarm(0)
 
 
-def plot(self, vars=None, autoscale=True, out = None, **kwargs):
+def plot(self, vars=None, autoscale=True, out = None, coast= False, **kwargs):
     from ncplot import view
 
     """
@@ -33,9 +34,11 @@ def plot(self, vars=None, autoscale=True, out = None, **kwargs):
 
     out: str
         Name of output file if you want to save as html. Defaults to None.
+    coast: bool
+        Set to True if you want a coastline to show up on spatial map. Default is False
 
     **kwargs: Optional args to be sent to hvplot
-         
+
 
     Examples
     ------------
@@ -57,6 +60,9 @@ def plot(self, vars=None, autoscale=True, out = None, **kwargs):
     # run any commands
     self.run()
 
+    if session_info["coast"]:
+        coast = True
+
     if len(self) > 1:
         raise TypeError("You cannot view multiple files!")
 
@@ -66,25 +72,25 @@ def plot(self, vars=None, autoscale=True, out = None, **kwargs):
                 "Unable to plot datasets when variables have differing levels"
             )
 
-    if type(vars) is str:
+    if isinstance(vars, str):
         vars = [vars]
 
-    if type(vars) is not list and vars is not None:
+    if not isinstance(vars, list) and vars is not None:
         raise ValueError("vars must be a list")
     if vars is None:
         vars = self.variables
 
-    if type(vars) is list:
+    if isinstance(vars, list):
         if len(set(self.contents.query("variable in @vars").nlevels)) > 1:
             raise ValueError(
                 "Unable to plot datasets when variables have differing levels"
             )
     if vars is None and len(self.variables) > 1:
         with time_limit(20):
-            return view(self[0], autoscale=autoscale, **kwargs)
+            return view(self[0], autoscale=autoscale, coast= coast, **kwargs)
 
-    if type(vars) is list and len(vars) > 1:
+    if isinstance(vars, list) and len(vars) > 1:
         with time_limit(20):
-            return view(self[0], vars=vars, autoscale=autoscale, out = out,  **kwargs)
+            return view(self[0], vars=vars, autoscale=autoscale, out = out, coast = coast,  **kwargs)
 
-    return view(self[0], vars=vars, autoscale=autoscale, out = out,   **kwargs)
+    return view(self[0], vars=vars, autoscale=autoscale, out = out, coast= coast,   **kwargs)
